@@ -151,8 +151,8 @@ class Scorer:
         result = None
               
         if metricName in self.addedMetrics:
-            truth = np.array([self.recordResult[id]["truth"] for id in self.recordResult])
-            prediction = np.array([self.recordResult[id]["prediction"] for id in self.recordResult])
+            truth = np.concatenate([self.recordResult[id]["truth"] for id in self.recordResult], axis=0)
+            prediction = np.concatenate([self.recordResult[id]["prediction"] for id in self.recordResult], axis=0)
             self.results[metricName] = self.addedMetrics[metricName]["combine"](truth, prediction)
         if metricName in ["kappa", "accuracy"]:  # recalcuate from confusion
             self.combineMetric("confusion")
